Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComputeExpiration ¶ added in v0.1.2
ComputeExpiration computes the expiration time of the reservation. If d is 0, then the reservation is renewed forever.
Types ¶
type Reservation ¶ added in v0.1.2
type Reservation struct {
// Conn is the connection on which the reservation will be applied.
Conn *snet.Conn
// Daemon is the SCION Daemon to which the reservation RPCs will be sent.
Daemon net.Addr
// SubscriptionInfo describes the reservation parameters.
SubscriptionInfo bwallocation.SubscriptionInfo
}
Reservation contains all the information for registering a reservation for a connection.
Click to show internal directories.
Click to hide internal directories.